@@ -19,10 +19,12 @@
 import typer
 import veda_cli.applications
 import veda_cli.datasets
+import veda_cli.executions
 
 app = typer.Typer()
 app.add_typer(veda_cli.applications.app, name="application")
 app.add_typer(veda_cli.datasets.app, name="dataset")
+app.add_typer(veda_cli.executions.app, name="execution")
 
 
 if __name__ == "__main__":
